#ifndef DATA_PACKAGE_LINE_H
#define DATA_PACKAGE_LINE_H

#include <iostream>
#include <vector>
#include <mutex>
#include <memory>

#include "vision/include/coordinate_util.h"
#include "interface/common_type.h"
#include "interface/slam_odometry.h"
#include "interface/slam_road_model.h"
#include "interface/slam_rtk_data.h"

#include "util/slam_util.h"

#define DEG2RAD 0.01745329

namespace slam
{

    class PackageLine
    {
    public:

        PackageLine();
        //~PackageLine(){};

        void Init();

        void SetHostVehiclePosition(const InsData& _ins);

        bool PackageOdom(slam::slam_odometry & odom_);
        bool PackageRM(std::vector<line_point>& points_);

        std::vector<slam::Vector2d> GetRefLine()
        {
            return ref_line_;
        }

        std::vector<slam::Vector3d> c_line;

    private:

        slam::Vector2d GetVectorPoint(double lat, double lon);

        double base_lon_ = 117;
        slam::Vector2d start_point_;

        std::vector<slam::Vector2d> ref_line_;
        std::vector<slam::Vector3d> ref_line_curve_;

        slam::Vector2d  cur_host_pos;
        double cur_host_heading;

        std::uint64_t last_odom_utc_ = 0;

        InsData cur_ins_;

        bool extract_loop_flag{false};

        SlamUtil::slam_kd_tree_t* cur_kd_tree_{nullptr};

        //std::mutex odom_mutex;

        //std::shared_ptr<slam_road_model> cur_rm_p;

//        traffic_lane lane0;
//        traffic_object obj;

        //slam_road_model cur_rm_p;
    };

}

#endif
